[Xfce4-commits] [xfce/thunar] 01/01: preferences: Add button icons to Help/Close
noreply at xfce.org
noreply at xfce.org
Thu Aug 8 18:14:18 CEST 2019
This is an automated email from the git hooks/post-receive script.
a n d r e p u s h e d a c o m m i t t o b r a n c h x f c e - 4 . 1 4
in repository xfce/thunar.
commit ddf251c0f22dfd3356d1d2b769a8bd7ef4396e4b
Author: Andre Miranda <andreldm at xfce.org>
Date: Thu Aug 8 13:13:21 2019 -0300
preferences: Add button icons to Help/Close
---
thunar/thunar-preferences-dialog.c | 19 ++++++++++++++-----
1 file changed, 14 insertions(+), 5 deletions(-)
diff --git a/thunar/thunar-preferences-dialog.c b/thunar/thunar-preferences-dialog.c
index 101c5fa..ffa9c0d 100644
--- a/thunar/thunar-preferences-dialog.c
+++ b/thunar/thunar-preferences-dialog.c
@@ -229,6 +229,7 @@ thunar_preferences_dialog_init (ThunarPreferencesDialog *dialog)
GtkWidget *button;
GtkWidget *combo;
GtkWidget *entry;
+ GtkWidget *image;
GtkWidget *frame;
GtkWidget *label;
GtkWidget *range;
@@ -248,11 +249,19 @@ thunar_preferences_dialog_init (ThunarPreferencesDialog *dialog)
gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
gtk_window_set_title (GTK_WINDOW (dialog), _("File Manager Preferences"));
- /* add "Help" and "Close" buttons */
- gtk_dialog_add_buttons (GTK_DIALOG (dialog),
- _("_Close"), GTK_RESPONSE_CLOSE,
- _("_Help"), GTK_RESPONSE_HELP,
- NULL);
+ /* add the "Close" button */
+ button = gtk_button_new_with_mnemonic (_("_Close"));
+ image = gtk_image_new_from_icon_name ("window-close", GTK_ICON_SIZE_BUTTON);
+ gtk_button_set_image (GTK_BUTTON (button), image);
+ gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button, GTK_RESPONSE_CLOSE);
+ gtk_widget_show (button);
+
+ /* add the "Help" button */
+ button = gtk_button_new_with_mnemonic (_("_Help"));
+ image = gtk_image_new_from_icon_name ("help-browser", GTK_ICON_SIZE_BUTTON);
+ gtk_button_set_image (GTK_BUTTON (button), image);
+ gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button, GTK_RESPONSE_HELP);
+ gtk_widget_show (button);
notebook = gtk_notebook_new ();
gtk_container_set_border_width (GTK_CONTAINER (notebook), 6);
--
To stop receiving notification emails like this one, please contact
the administrator of this repository.
More information about the Xfce4-commits
mailing list